@@ -1,70 +1,111 @@
-## ---- include=FALSE---------------------------------------------------------------------------------------------------
-knitr::opts_chunk$set(fig.width=4, fig.height=3.5)
+## ----include=FALSE----------------------------------------------------------------------------------------------------
+knitr::opts_chunk$set(fig.width=6, fig.height=3.5)
 
 ## ----include=FALSE----------------------------------------------------------------------------------------------------
 suppressPackageStartupMessages(library("lessR"))
 
 ## ---------------------------------------------------------------------------------------------------------------------
-d <- Read("Employee")
+style(quiet=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 getColors("hues")
 
-## ---------------------------------------------------------------------------------------------------------------------
-getColors(in_order=TRUE)
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors("hues", output=TRUE)
 
-## ---------------------------------------------------------------------------------------------------------------------
+## ---- fig.height=6, fig.width=6---------------------------------------------------------------------------------------
 getColors(n=36, shape="wheel", border="off")
 
+## ----echo=FALSE, fig.height=6, fig.width=6----------------------------------------------------------------------------
+getColors(n=36, shape="wheel", border="off", output=TRUE)
+
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors(c=90, l=45))
+getColors(c=50, l=30)
+
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors(c=50, l=30, output=TRUE)
+
+## ---------------------------------------------------------------------------------------------------------------------
+d <- Read("Employee", quiet=TRUE)
+BarChart(Dept, fill=getColors(c=50, l=30), quiet=TRUE)
+
+## ---------------------------------------------------------------------------------------------------------------------
+myColors <- getColors(c=90, l=80, n=5)
+BarChart(Dept, fill=myColors, values_color="gray20", quiet=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 #showPalettes()
 
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors("blues"))
+getColors("blues")
+
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors("blues", output=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors("blues", c=60, l=c(30,80)))
+getColors("blues", c=60, l=c(30,80))
+
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors("blues", c=60, l=c(30,80), output=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors("browns", c=c(20,90), l=60))
+getColors("browns", c=c(20,90), l=60)
+
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors("browns", c=c(20,90), l=60, output=TRUE)
 
 ## ---- fig.width=6-----------------------------------------------------------------------------------------------------
-d <- Read("StockPrice", quiet=TRUE)
-Plot(date, Price, by=Company, trans=0.4, stack=TRUE, area_fill="reds")
-d <- Read("Employee", quiet=TRUE)
+d2 <- Read("StockPrice", quiet=TRUE)
+Plot(date, Price, by=Company, stack=TRUE, area_fill="reds", trans=0.4, data=d2)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors("rusts", "blues"))
+getColors("rusts", "blues")
+
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors("rusts", "blues", output=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors("rusts", "blues", c=45))
+getColors("rusts", "blues", c=75)
+
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+getColors("rusts", "blues", c=75, output=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-BarChart(Dept, fill=getColors(c=90, l=45))
+values <- c(rep(1,2), rep(2,5), rep(3,4), rep(4,3), rep(5,6), rep(6,7), rep(7,8))
+Responses <- sample(values, size=100, replace=TRUE)
+
+LikertCats <- c("Strongly Disagree", "Disagree", "Slightly Disagree",
+                "Neutral", "Slightly Agree", "Agree", "Strongly Agree")
+Responses <- factor(Responses, levels=1:7, labels=LikertCats)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors(c("black", "blue", "red"))
+red <- getColors("reds", n=3, c=c(75,35), l=c(27,63))
+blue <- getColors("blues", n=3)
 
 ## ---------------------------------------------------------------------------------------------------------------------
-getColors(pal="aliceblue", end_pal="blue")
+BarChart(Responses, fill=c(red, "gray50", blue))
+
+## ---------------------------------------------------------------------------------------------------------------------
+d <- Read("Employee")
+
+## ---------------------------------------------------------------------------------------------------------------------
+style("gray")
+BarChart(Dept)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 style("darkred")
-BarChart(Dept)
+BarChart(Dept, quiet=TRUE)
 
-## ---------------------------------------------------------------------------------------------------------------------
-style()
+## ----fig.height=6-----------------------------------------------------------------------------------------------------
+Plot(Salary, by1=Dept, quiet=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 style(window_fill="aliceblue")
-BarChart(Dept)
-
-## ---------------------------------------------------------------------------------------------------------------------
-style()
+BarChart(Dept, theme="sienna")
 
 ## ---------------------------------------------------------------------------------------------------------------------
 style(show=TRUE)
 
+## ----echo=FALSE-------------------------------------------------------------------------------------------------------
+style()
+
