@@ -4,6 +4,9 @@ suppressPackageStartupMessages(library("lessR"))
 ## ----read-------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
 
+## ----labels-----------------------------------------------------------------------------------------------------------
+l <- rd("Employee_lbl")
+
 ## ---------------------------------------------------------------------------------------------------------------------
 ttest(Salary)
 
@@ -36,7 +39,7 @@ data(warpbreaks)
 dm <- pivot(warpbreaks, mean, breaks, c(tension, wool))
 dm
 
-## ---------------------------------------------------------------------------------------------------------------------
+## ----fig.width=5------------------------------------------------------------------------------------------------------
 Plot(tension, breaks_mn, by=wool, segments=TRUE, size=2, data=dm, main="Cell Means")
 
 ## ---------------------------------------------------------------------------------------------------------------------
